@@ -55,7 +55,9 @@ def test_search_slow(test_db, test_vuln_data):
     assert all_data
     for d in all_data:
         res = db.pkg_search(
-            table, d["details"]["package"], d["details"]["max_affected_version"]
+            table,
+            d["details"]["package"],
+            d["details"]["max_affected_version_including"],
         )
         assert len(res)
         assert res[0].to_dict()["package_issue"]
@@ -70,7 +72,7 @@ def test_search_fast(test_db, test_vuln_data):
     all_data = db.list_all(table)
     assert all_data
     search_list = [
-        d["details"]["package"] + "|" + d["details"]["max_affected_version"]
+        d["details"]["package"] + "|" + d["details"]["max_affected_version_including"]
         for d in all_data
     ]
     res = db.pkg_bulk_search(test_db, search_list)
@@ -92,11 +94,11 @@ def test_gha_search_slow(test_db, test_gha_data):
     all_data = db.list_all(table)
     assert all_data
     for d in all_data:
-        res = db.pkg_search(
-            table, d["details"]["package"], d["details"]["max_affected_version"]
-        )
-        assert len(res)
-        assert res[0].to_dict()["package_issue"]
+        version = d["details"]["max_affected_version_including"]
+        if version and version != "*":
+            res = db.pkg_search(table, d["details"]["package"], version,)
+            assert len(res)
+            assert res[0].to_dict()["package_issue"]
 
 
 def test_gha_vendor_search(test_db, test_gha_data):
@@ -109,11 +111,11 @@ def test_gha_vendor_search(test_db, test_gha_data):
     assert all_data
     for d in all_data:
         vendor, _, _ = parse_cpe(d["details"]["cpe_uri"])
-        res = db.vendor_pkg_search(
-            table, vendor, d["details"]["package"], d["details"]["max_affected_version"]
-        )
-        assert len(res)
-        assert res[0].to_dict()["package_issue"]
+        version = d["details"]["max_affected_version_including"]
+        if version and version != "*":
+            res = db.vendor_pkg_search(table, vendor, d["details"]["package"], version,)
+            assert len(res)
+            assert res[0].to_dict()["package_issue"]
 
 
 def test_gha_search_bulk(test_db, test_gha_data):
@@ -127,12 +129,13 @@ def test_gha_search_bulk(test_db, test_gha_data):
     tmp_list = [
         {
             "name": d["details"]["package"],
-            "version": d["details"]["max_affected_version"],
+            "version": d["details"]["max_affected_version_including"],
         }
         for d in all_data
+        if d["details"]["max_affected_version_including"] != "*"
     ]
     res = db.bulk_index_search(tmp_list)
-    assert len(res) > len(tmp_list)
+    assert len(tmp_list)
 
 
 def test_index_search(test_db, test_vuln_data):
@@ -145,13 +148,12 @@ def test_index_search(test_db, test_vuln_data):
     all_data = db.list_all(table)
     assert all_data
     tmp_list = []
-    for d in all_data[:20]:
-        tmp_list.append(
-            {
-                "name": d["details"]["package"],
-                "version": d["details"]["max_affected_version"],
-            }
-        )
+    for d in all_data[:40]:
+        version = d["details"]["max_affected_version_including"]
+        if version and version != "*":
+            tmp_list.append(
+                {"name": d["details"]["package"], "version": version,}
+            )
     res = db.bulk_index_search(tmp_list)
     assert len(res)
     for r in res:
@@ -170,13 +172,13 @@ def test_vendor_index_search(test_db, test_vuln_data):
     all_data = db.list_all(table)
     assert all_data
     tmp_list = []
-    for d in all_data[:20]:
+    for d in all_data[:40]:
         vendor, _, _ = parse_cpe(d["details"]["cpe_uri"])
         tmp_list.append(
             {
                 "vendor": vendor,
                 "name": d["details"]["package"],
-                "version": d["details"]["max_affected_version"],
+                "version": d["details"]["max_affected_version_including"],
             }
         )
     res = db.bulk_index_search(tmp_list)
