@@ -3,6 +3,7 @@
 
 import argparse
 import logging
+import os
 import re
 
 from tabulate import tabulate
@@ -37,6 +38,13 @@ def build_args():
     parser = argparse.ArgumentParser(
         description="AppThreat's vulnerability database and package search library with a built-in file based storage"
     )
+    parser.add_argument(
+        "--clean",
+        action="store_true",
+        default=False,
+        dest="clean",
+        help="Clear the vulnerability database cache from platform specific user_data_dir",
+    )
     parser.add_argument(
         "--cache",
         action="store_true",
@@ -125,13 +133,21 @@ def print_results(results):
 def main():
     args = build_args()
     print(at_logo)
-    LOG.info("Vulnerability database loaded from {}".format(config.vdb_bin_file))
+    if args.clean:
+        if os.path.exists(config.data_dir):
+            try:
+                os.rmdir(config.data_dir)
+            except Exception:
+                pass
+    else:
+        LOG.info("Vulnerability database loaded from {}".format(config.vdb_bin_file))
+
     if args.cache:
-        for s in [GitHubSource(), NvdSource()]:
+        for s in [NvdSource(), GitHubSource()]:
             LOG.info("Refreshing {}".format(s.__class__.__name__))
             s.refresh()
     elif args.sync:
-        for s in [GitHubSource(), NvdSource()]:
+        for s in [NvdSource(), GitHubSource()]:
             LOG.info("Syncing {}".format(s.__class__.__name__))
             s.download_recent()
     if args.sync_npm:
