@@ -171,8 +171,6 @@ class GitHubSource(NvdSource):
 
     def convert(self, cve_data):
         """Convert the GitHub advisory data into Vulnerability objects
-
-        TODO: Fix version information is getting ignored since the CVE Json format does not support this attribute
         """
         ret_data = []
         if cve_data.get("errors"):
@@ -180,7 +178,7 @@ class GitHubSource(NvdSource):
         if cve_data.get("message") and cve_data.get("message") == "Bad credentials":
             LOG.warning("GITHUB_TOKEN environment variable is invalid!")
             return ret_data, None
-        page_info = cve_data["data"]["securityAdvisories"]["pageInfo"]
+        page_info = cve_data["data"]["securityAdvisories"].get("pageInfo")
         for cve in cve_data["data"]["securityAdvisories"]["nodes"]:
             cve_id = None
             assigner = "cve@mitre.org"
