@@ -271,6 +271,9 @@ def convert_to_semver(version):
     }
     ver = VersionInfo(**ver)
     rest = match.string[match.end() :]  # noqa:E203
+    number_part = convert_to_num(rest)
+    if not number_part:
+        rest = None
     return ver, rest
 
 
@@ -301,6 +304,8 @@ def version_compare(
     if (not max_version or max_version == "*") and max_affected_version_excluding:
         max_version = max_affected_version_excluding
         is_max_exclude = True
+    if not min_version:
+        min_version = "0"
     # Perform semver match once we have all the required versions
     if compare_ver and min_version and max_version:
         if semver_compatible(compare_ver, min_version, max_version):
@@ -312,7 +317,9 @@ def version_compare(
 
         # We have an incompatible semver string. Try to convert to semver format
         compare_semver, comprest = convert_to_semver(compare_ver)
-        min_semver, minrest = convert_to_semver(min_version)
+        min_semver, minrest = convert_to_semver(
+            "0.0.0" if min_version == "*" else min_version
+        )
         max_semver, maxrest = convert_to_semver(max_version)
         if (
             compare_semver
@@ -331,8 +338,6 @@ def version_compare(
     compare_ver_build = None
     min_version_build = None
     max_version_build = None
-    if not min_version:
-        min_version = "0"
     # Extract any build string such as alpha or beta
     if "-" in compare_ver and compare_ver != "-":
         tmpA = compare_ver.split("-")
